Version class

The description of a QR code version

Constructors

Version({int? infoBits, required int versionNumber, required List<int> alignmentPatternCenters, required List<ErrorCorrectionLevel> errorCorrectionLevels})
const

Properties

alignmentPatternCenters → List<int>
final
errorCorrectionLevels → List<ErrorCorrectionLevel>
final
hashCode → int
The hash code for this object.
no setterinherited
infoBits → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
versionNumber → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited