BitMatrix class

Constructors

BitMatrix(Uint8ClampedList _data, int width)

Properties

hashCode → int
The hash code for this object.
no setterinherited
height → int
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
width → int
final

Methods

get(int x, int y) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(int x, int y, bool v) → dynamic
setRegion(int left, int top, int width, int height, bool v) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

createEmpty(int width, int height) → BitMatrix